==> clashcross-v1.0.2.zip: clashcross-v1.0.2/README_zh.md <==
# ClashCross

<p align="center"><img src="assets/images/multiclash.png" style="border-radius: 50%" width="150px"/></p>

<p align="center" style="font-size: 20px">ClashCross是基于Clash核心构建的代理调试应用。</p>
<p align="center" style="font-size: 16px">我们不提供任何相关服务，请不要反馈与应用本身使用无关的问题。</p>
<p align="center" style="font-size: 16px">支持Android（测试版）/ Windows / macOS / Linux（amd64/arm64）！</p>
<p align="left" style="font-size: 16px"><a href="README.md">
      English
      </a><a href="README_zh.md">
      简体中文
      </a></p>

# 安装

## Android

<a href='https://play.google.com/store/apps/details?id=com.clashcross.clashcross&pcampaignid=pcampaignidMKT-Other-global-all-co-prtnr-py-PartBadge-Mar2515-1'><img alt='在Google Play上获取' src='https://play.google.com/intl/en_us/badges/static/images/badges/en_badge_web_generic.png' style="width:250px"/></a>

或直接下载.apk文件。[https://github.com/shipinbaoku/ClashCross/releases](https://github.com/shipinbaoku/ClashCross/releases)

## Windows

请直接下载.exe安装文件。https://github.com/shipinbaoku/ClashCross/releases

## Macos

请直接下载.dmg安装文件。[https://github.com/shipinbaoku/ClashCross/releases](https://github.com/shipinbaoku/ClashCross/releases)

## Linux

- snap包：
    - `snap install clashcross`
    - <a href="https://snapcraft.io/clashcross">
      <img alt="从Snap Store获取" src="https://snapcraft.io/static/images/badges/en/snap-store-white.svg" />
      </a>
- deb包：
    - `sudo apt install libappindicator3-dev`
    - <p>然后</p>
    - `sudo dpkg -i clashcross.deb`

## Windows

请直接下载.exe安装文件。[https://github.com/shipinbaoku/ClashCross/releases](https://github.com/shipinbaoku/ClashCross/releases)

# 界面预览

- 主页

  ![image](docs/screenshot/photo_2023-07-27_05-03-12.jpg)
- 代理

  ![image](docs/screenshot/photo_2023-07-27_05-03-34.jpg)
- 配置文件

  ![image](docs/screenshot/photo_2023-07-27_05-03-59.jpg)
- 设置

  ![image](docs/screenshot/photo_2023-07-27_05-04-13.jpg)
- 连接信息

  ![image](docs/screenshot/photo_2023-07-27_05-04-24.jpg)
- 日志

  ![image](docs/screenshot/photo_2023-07-27_05-05-03.jpg)

# 致谢：

- [clash](https://github.com/Dreamacro/clash)
- [flcash](https://github.com/Fclash/Fclash)
- [flutter](https://github.com/flutter/flutter)

==> clashcross-v1.0.3.zip: clashcross-v1.0.3/README_zh.md <==
# ClashCross

<p align="center"><img src="assets/images/multiclash.png" style="border-radius: 50%" width="150px"/></p>

<p align="center" style="font-size: 20px">ClashCross是基于Clash核心构建的代理调试应用。</p>
<p align="center" style="font-size: 16px">我们不提供任何相关服务，请不要反馈与应用本身使用无关的问题。</p>
<p align="center" style="font-size: 16px">支持Android（测试版）/ Windows / macOS / Linux（amd64/arm64）！</p>
<p align="left" style="font-size: 16px"><a href="README.md">
      English
      </a><a href="README_zh.md">
      简体中文
      </a></p>

# 安装

## Android

<a href='https://play.google.com/store/apps/details?id=com.clashcross.clashcross&pcampaignid=pcampaignidMKT-Other-global-all-co-prtnr-py-PartBadge-Mar2515-1'><img alt='在Google Play上获取' src='https://play.google.com/intl/en_us/badges/static/images/badges/en_badge_web_generic.png' style="width:250px"/></a>

或直接下载.apk文件。[https://github.com/shipinbaoku/ClashCross/releases](https://github.com/shipinbaoku/ClashCross/releases)

## Windows

请直接下载.exe安装文件。[https://github.com/shipinbaoku/ClashCross/releases](https://github.com/shipinbaoku/ClashCross/releases)

## Macos

请直接下载.dmg安装文件。[https://github.com/shipinbaoku/ClashCross/releases](https://github.com/shipinbaoku/ClashCross/releases)

## Linux

- snap包：
    - `snap install clashcross`
    - <a href="https://snapcraft.io/clashcross">
      <img alt="从Snap Store获取" src="https://snapcraft.io/static/images/badges/en/snap-store-white.svg" />
      </a>
- deb包：
    - `sudo apt install libappindicator3-dev`
    - <p>然后</p>
    - `sudo dpkg -i clashcross.deb`

## Windows

请直接下载.exe安装文件。[https://github.com/shipinbaoku/ClashCross/releases](https://github.com/shipinbaoku/ClashCross/releases)

# Url_scheme 
我们的应用程序允许第三方通过url_scheme方式导入clash订阅，规范如下：
## android：clashcross://?url=订阅链接
## windows&macos：clashcross://?url=订阅链接
## linux：暂不支持，需要用户手动复制粘贴导入
## <a href="/docs/zh/url_scheme.md">具体说明</a>


# 界面预览

- 主页

  ![image](docs/screenshot/photo_2023-07-27_05-03-12.jpg)
- 代理

  ![image](docs/screenshot/photo_2023-07-27_05-03-34.jpg)
- 配置文件

  ![image](docs/screenshot/photo_2023-07-27_05-03-59.jpg)
- 设置

  ![image](docs/screenshot/photo_2023-07-27_05-04-13.jpg)
- 连接信息

  ![image](docs/screenshot/photo_2023-07-27_05-04-24.jpg)
- 日志

  ![image](docs/screenshot/photo_2023-07-27_05-05-03.jpg)

# 致谢：

- [clash](https://github.com/Dreamacro/clash)
- [flcash](https://github.com/Fclash/Fclash)
- [flutter](https://github.com/flutter/flutter)
